==> mysql-router-2.0.3.tar.gz: mysql-router-2.0.3/src/routing/src/utils.h <==
/*
  Copyright (c) 2015, 2016, Oracle and/or its affiliates. All rights reserved.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; version 2 of the License.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef UTILS_ROUTING_INCLUDED
#define UTILS_ROUTING_INCLUDED

#include <array>
#include <iostream>
#include <netinet/in.h>
#include <netdb.h>
#include <unistd.h>
#include <sstream>
#include <vector>

using std::string;

/**
 * Socket address from either IPv4 or IPv6
 *
 * @param addr addrinfo struct
 * @return struct in_addr
 */
void * get_in_addr(struct sockaddr *addr);

/**
 * IP Address from addrinfo struct
 *
 * @param addrinfo addrinfo struct
 * @return std::string
 */
string ip_from_addrinfo(struct addrinfo *info);

/**
 * Get address of connected peer
 *
 * Get address of connected peer connected to the specified
 * socket. This works similar as getpeername() but will handle
 * both IPv4 and IPv6.
 *
 * @param int socket
 * @return std::pair with std::string and uint16_t
 */
std::pair<std::string, int > get_peer_name(int sock);

/**
 * Splits a string using a delimiter
 *
 * @param data a string to split
 * @param delimiter a char used as delimiter
 * @param bool whether to allow empty tokens or not (default true)
 * @return std::vector<string> containing tokens
 */
std::vector<string> split_string(const string& data, const char delimiter, bool allow_empty);

/** @overload */
std::vector<string> split_string(const string& data, const char delimiter);

/** @brief Converts IPv6 in6_addr to std::array
 *
 * Converts a IPv6 address stored in a in6_addr struct to a
 * std::array of size 16.
 *
 * @param addr a in6_addr struct
 * @return std::array<uint8_t, 16>
 */
std::array<uint8_t, 16> in6_addr_to_array(in6_addr addr);

#endif // UTILS_ROUTING_INCLUDED

==> mysql-router-2.1.6.tar.gz: mysql-router-2.1.6/src/routing/src/utils.h <==
/*
  Copyright (c) 2015, 2016, Oracle and/or its affiliates. All rights reserved.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; version 2 of the License.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef UTILS_ROUTING_INCLUDED
#define UTILS_ROUTING_INCLUDED

#include <array>
#include <iostream>
#include <sstream>
#include <vector>
#ifndef _WIN32
# include <netinet/in.h>
# include <netdb.h>
# include <unistd.h>
#else
# define WIN32_LEAN_AND_MEAN
# include <windows.h>
# include <winsock2.h>
# include <ws2tcpip.h>
# include <stdint.h>
#endif

/**
 * Socket address from either IPv4 or IPv6
 *
 * @param addr addrinfo struct
 * @return struct in_addr
 */
void * get_in_addr(struct sockaddr *addr);

/**
 * Get address of connected peer
 *
 * Get address of peer connected to the specified
 * socket. This works similar as getpeername() but will handle
 * IPv4, IPv6 and Unix sockets/Windows named pipes.
 *
 * @param int socket
 * @return std::pair with std::string and uint16_t
 */
std::pair<std::string, int > get_peer_name(int sock);

/**
 * Splits a string using a delimiter
 *
 * @param data a string to split
 * @param delimiter a char used as delimiter
 * @param bool whether to allow empty tokens or not (default true)
 * @return std::vector<string> containing tokens
 */
std::vector<std::string> split_string(const std::string& data, const char delimiter, bool allow_empty);

/** @overload */
std::vector<std::string> split_string(const std::string& data, const char delimiter);

/** @brief Converts IP addr to std::array
 *
 * Converts a IP address stored in a sockaddr_storage struct to a
 * std::array of size 16.
 *
 * @param addr a sockaddr_storage struct
 * @return std::array<uint8_t, 16>
 */
std::array<uint8_t, 16> in_addr_to_array(const sockaddr_storage& addr);

std::string get_message_error(int errcode);

#endif // UTILS_ROUTING_INCLUDED
